@@ -316,77 +316,9 @@ void CAccountManagerPropertiesPage::OnStateChange( CAccountManagerPropertiesPage
                 } else {
                     SetProjectPropertiesURLFailure(false);
                 }
-                SetNextState(ACCTMGRPROP_COMMUNICATEYAHOO_BEGIN);
+                SetNextState(ACCTMGRPROP_DETERMINENETWORKSTATUS_BEGIN);
             }
             break;
-        case ACCTMGRPROP_COMMUNICATEYAHOO_BEGIN:
-            SetNextState(ACCTMGRPROP_COMMUNICATEYAHOO_EXECUTE);
-            break;
-        case ACCTMGRPROP_COMMUNICATEYAHOO_EXECUTE:
-            // Attempt to successfully download the Yahoo homepage
-            pDoc->rpc.lookup_website(LOOKUP_YAHOO);
- 
-            // Wait until we are done processing the request.
-            dtStartExecutionTime = wxDateTime::Now();
-            dtCurrentExecutionTime = wxDateTime::Now();
-            tsExecutionTime = dtCurrentExecutionTime - dtStartExecutionTime;
-            iReturnValue = ERR_IN_PROGRESS;
-            while (ERR_IN_PROGRESS == iReturnValue &&
-                   tsExecutionTime.GetSeconds() <= 60 &&
-                   !CHECK_CLOSINGINPROGRESS()
-                  )
-            {
-                dtCurrentExecutionTime = wxDateTime::Now();
-                tsExecutionTime = dtCurrentExecutionTime - dtStartExecutionTime;
-                iReturnValue = pDoc->rpc.lookup_website_poll();
-                IncrementProgress(m_pProgressIndicator);
-
-                ::wxMilliSleep(500);
-                ::wxSafeYield(GetParent());
-            }
- 
-            if ((BOINC_SUCCESS == iReturnValue) && !CHECK_DEBUG_FLAG(WIZDEBUG_ERRYAHOOCOMM)) {
-                SetCommunicateYahooSucceeded(true);
-            } else {
-                SetCommunicateYahooSucceeded(false);
-            }
-
-            SetNextState(ACCTMGRPROP_COMMUNICATEGOOGLE_BEGIN);
-            break;
-        case ACCTMGRPROP_COMMUNICATEGOOGLE_BEGIN:
-            SetNextState(ACCTMGRPROP_COMMUNICATEGOOGLE_EXECUTE);
-            break;
-        case ACCTMGRPROP_COMMUNICATEGOOGLE_EXECUTE:
-            // Attempt to successfully download the Google homepage
-            pDoc->rpc.lookup_website(LOOKUP_GOOGLE);
- 
-            // Wait until we are done processing the request.
-            dtStartExecutionTime = wxDateTime::Now();
-            dtCurrentExecutionTime = wxDateTime::Now();
-            tsExecutionTime = dtCurrentExecutionTime - dtStartExecutionTime;
-            iReturnValue = ERR_IN_PROGRESS;
-            while (ERR_IN_PROGRESS == iReturnValue &&
-                   tsExecutionTime.GetSeconds() <= 60 &&
-                   !CHECK_CLOSINGINPROGRESS()
-                  )
-            {
-                dtCurrentExecutionTime = wxDateTime::Now();
-                tsExecutionTime = dtCurrentExecutionTime - dtStartExecutionTime;
-                iReturnValue = pDoc->rpc.lookup_website_poll();
-                IncrementProgress(m_pProgressIndicator);
-
-                ::wxMilliSleep(500);
-                ::wxSafeYield(GetParent());
-            }
- 
-            if ((BOINC_SUCCESS == iReturnValue) && !CHECK_DEBUG_FLAG(WIZDEBUG_ERRGOOGLECOMM)) {
-                SetCommunicateGoogleSucceeded(true);
-            } else {
-                SetCommunicateGoogleSucceeded(false);
-            }
-
-            SetNextState(ACCTMGRPROP_DETERMINENETWORKSTATUS_BEGIN);
-            break;
         case ACCTMGRPROP_DETERMINENETWORKSTATUS_BEGIN:
             SetNextState(ACCTMGRPROP_DETERMINENETWORKSTATUS_EXECUTE);
             break;
