@@ -536,6 +536,7 @@ bool CBOINCGUIApp::IsBOINCCoreRunning() {
     wxLogTrace(wxT("Function Start/End"), wxT("CBOINCGUIApp::IsBOINCCoreRunning - Function Begin"));
 
     int retval;
+    int scrsave_mode;
     bool running;
     RPC_CLIENT rpc;
 
@@ -545,12 +546,14 @@ bool CBOINCGUIApp::IsBOINCCoreRunning() {
         running = (FALSE != IsBOINCServiceStarting()) || (FALSE != IsBOINCServiceRunning());
     } else {
         retval = rpc.init("localhost");  // synchronous is OK since local
+        retval = rpc.get_screensaver_mode(scrsave_mode);
         running = (retval == 0);
         rpc.close();
     }
     
 #else
     retval = rpc.init("localhost");  // synchronous is OK since local
+    retval = rpc.get_screensaver_mode(scrsave_mode);
     running = (retval == 0);
     rpc.close();
 #endif
@@ -945,4 +948,4 @@ int CBOINCGUIApp::StartBOINCScreensaverTest() {
 }
 
 
-const char *BOINC_RCSID_487cbf3018 = "$Id: BOINCGUIApp.cpp,v 1.116.2.11 2006/05/02 19:41:12 rwalton Exp $";
+const char *BOINC_RCSID_487cbf3018 = "$Id: BOINCGUIApp.cpp,v 1.116.2.12 2006/08/02 21:53:39 rwalton Exp $";
