@@ -366,11 +366,11 @@ bool CMainFrame::CreateMenu() {
     } else {
         strMenuName.Printf(
             _("&Synchronize with %s"), 
-            ami.acct_mgr_name.c_str()
+            wxString(ami.acct_mgr_name.c_str(), wxConvUTF8).c_str()
         );
         strMenuDescription.Printf(
             _("Get current settings from %s"), 
-            ami.acct_mgr_name.c_str()
+            wxString(ami.acct_mgr_name.c_str(), wxConvUTF8).c_str()
         );
         menuTools->Append(
             ID_TOOLSAMUPDATENOW, 
@@ -448,7 +448,7 @@ bool CMainFrame::CreateMenu() {
     if (is_acct_mgr_detected) {
         strMenuName.Printf(
             _("&Defect from %s"), 
-            ami.acct_mgr_name.c_str()
+            wxString(ami.acct_mgr_name.c_str(), wxConvUTF8).c_str()
         );
         menuAdvanced->Append(
             ID_ADVANCEDAMDEFECT, 
@@ -1220,7 +1220,7 @@ void CMainFrame::OnAccountManagerDetach(wxCommandEvent& WXUNUSED(event)) {
 
         strTitle.Printf(
             _("BOINC Manager - Detach from %s"), 
-            ami.acct_mgr_name.c_str()
+            wxString(ami.acct_mgr_name.c_str(), wxConvUTF8).c_str()
         );
         strMessage.Printf(
             _("If you defect from %s,\n"
@@ -1228,8 +1228,8 @@ void CMainFrame::OnAccountManagerDetach(wxCommandEvent& WXUNUSED(event)) {
               "but you'll have to manage projects manually.\n"
               "\n"
               "Do you want to defect from %s?"), 
-            ami.acct_mgr_name.c_str(),
-            ami.acct_mgr_name.c_str()
+            wxString(ami.acct_mgr_name.c_str(), wxConvUTF8).c_str(),
+            wxString(ami.acct_mgr_name.c_str(), wxConvUTF8).c_str()
         );
 
         iAnswer = ::wxMessageBox(
@@ -1672,6 +1672,8 @@ void CMainFrame::OnConnect(CMainFrameEvent&) {
     wxString strComputer = wxEmptyString;
     wxString strName = wxEmptyString;
     wxString strURL = wxEmptyString;
+    wxString strDialogTitle = wxEmptyString;
+    wxString strDialogDescription = wxEmptyString;
     bool bCachedCredentials = false;
     ACCT_MGR_INFO ami;
     PROJECT_INIT_STATUS pis;
@@ -1711,6 +1713,30 @@ void CMainFrame::OnConnect(CMainFrameEvent&) {
         if (pAMWizard->Run()) {
             // If successful, hide the main window
             Hide();
+
+            // %s is the application name
+            //    i.e. 'BOINC Manager', 'GridRepublic Manager'
+            strDialogTitle.Printf(
+                _("%s"),
+                wxGetApp().GetBrand()->GetApplicationName().c_str()
+            );
+
+            // %s is the application name
+            //    i.e. 'BOINC Manager', 'GridRepublic Manager'
+            // %s is the project name
+            //    i.e. 'BOINC', 'GridRepublic'
+            strDialogDescription.Printf(
+                _("%s has successfully attached to %s"),
+                wxGetApp().GetBrand()->GetApplicationName().c_str(),
+                wxGetApp().GetBrand()->GetProjectName().c_str()
+            );
+
+            ShowAlert(
+                strDialogTitle,
+                strDialogDescription,
+                wxOK | wxICON_INFORMATION,
+                true
+            );
         } else {
             // If failure, display the messages tab
             m_pNotebook->SetSelection(ID_LIST_MESSAGESVIEW - ID_LIST_BASE);
@@ -2198,4 +2224,4 @@ void CMainFrameAlertEvent::ProcessResponse(const int response) const {
 }
 
 
-const char *BOINC_RCSID_d881a56dc5 = "$Id: MainFrame.cpp,v 1.225.2.8 2006/05/02 18:17:44 rwalton Exp $";
+const char *BOINC_RCSID_d881a56dc5 = "$Id: MainFrame.cpp,v 1.225.2.10 2006/08/03 08:31:04 rwalton Exp $";
